@@ -16,6 +16,7 @@ import (
 	"github.com/confluentinc/cli/v3/pkg/errors"
 	"github.com/confluentinc/cli/v3/pkg/flink/internal/controller"
 	"github.com/confluentinc/cli/v3/pkg/flink/internal/history"
+	"github.com/confluentinc/cli/v3/pkg/flink/internal/store"
 	"github.com/confluentinc/cli/v3/pkg/flink/internal/utils"
 	"github.com/confluentinc/cli/v3/pkg/flink/test"
 	"github.com/confluentinc/cli/v3/pkg/flink/test/mock"
@@ -58,7 +59,7 @@ func (s *ApplicationTestSuite) SetupTest() {
 		inputController:             s.inputController,
 		statementController:         s.statementController,
 		interactiveOutputController: s.interactiveOutputController,
-		basicOutputController:       s.basicOutputController,
+		baseOutputController:        s.basicOutputController,
 		refreshToken:                authenticated,
 		reportUsage:                 func() {},
 	}
@@ -198,7 +199,8 @@ func (s *ApplicationTestSuite) TestReplUsesInteractiveOutput() {
 func (s *ApplicationTestSuite) TestShouldUseTView() {
 	app := Application{
 		interactiveOutputController: &controller.InteractiveOutputController{},
-		basicOutputController:       &controller.BasicOutputController{},
+		baseOutputController:        &controller.BaseOutputController{},
+		store:                       &store.Store{},
 	}
 	tests := []struct {
 		name          string
@@ -267,9 +269,9 @@ func (s *ApplicationTestSuite) TestShouldUseTView() {
 	for _, tt := range tests {
 		s.T().Run(tt.name, func(t *testing.T) {
 			if tt.isBasicOutput {
-				actual, ok := app.getOutputController(tt.statement).(*controller.BasicOutputController)
+				actual, ok := app.getOutputController(tt.statement).(*controller.BaseOutputController)
 				require.True(t, ok)
-				require.Equal(t, app.basicOutputController, actual)
+				require.Equal(t, app.baseOutputController, actual)
 				return
 			}
 
