@@ -228,7 +228,7 @@ func (s *StatementControllerTestSuite) TestExecuteStatementPrintsNoWarningForSta
 }
 
 func (s *StatementControllerTestSuite) TestExecuteStatementWaitsForCompletedState() {
-	statementToExecute := "select 1;"
+	statementToExecute := "insert into users values ('test');"
 	processedStatement := types.ProcessedStatement{Status: types.PENDING, Principal: "sa-123"}
 	runningStatement := types.ProcessedStatement{Status: types.RUNNING}
 	completedStatement := types.ProcessedStatement{Status: types.COMPLETED}
@@ -248,7 +248,7 @@ func (s *StatementControllerTestSuite) TestExecuteStatementWaitsForCompletedStat
 }
 
 func (s *StatementControllerTestSuite) TestExecuteStatementWaitsForFailedState() {
-	statementToExecute := "select 1;"
+	statementToExecute := "insert into users values ('test');"
 	processedStatement := types.ProcessedStatement{Status: types.PENDING, Principal: "sa-123"}
 	runningStatement := types.ProcessedStatement{Status: types.RUNNING}
 	failedStatement := types.ProcessedStatement{Status: types.FAILED}
@@ -270,25 +270,23 @@ func (s *StatementControllerTestSuite) TestExecuteStatementWaitsForFailedState()
 func (s *StatementControllerTestSuite) TestExecuteStatementWaitsForNonEmptyPageToken() {
 	statementToExecute := "select 1;"
 	processedStatement := types.ProcessedStatement{Status: types.PENDING, Principal: "sa-123"}
-	runningStatement := types.ProcessedStatement{Status: types.RUNNING}
-	runningStatementWithNextPage := types.ProcessedStatement{Status: types.RUNNING, PageToken: "not-empty"}
+	runningStatement := types.ProcessedStatement{Status: types.RUNNING, PageToken: "not-empty"}
 	s.store.EXPECT().ProcessStatement(statementToExecute).Return(&processedStatement, nil)
 	s.consoleParser.EXPECT().Read().Return(nil, nil).AnyTimes()
 	s.store.EXPECT().WaitPendingStatement(gomock.Any(), processedStatement).Return(&runningStatement, nil)
 	s.store.EXPECT().FetchStatementResults(runningStatement).Return(&runningStatement, nil)
-	s.store.EXPECT().WaitForTerminalStatementState(gomock.Any(), runningStatement).Return(&runningStatementWithNextPage, nil)
 
 	stdout := testUtils.RunAndCaptureSTDOUT(s.T(), func() {
 		returnedStatement, err := s.statementController.ExecuteStatement(statementToExecute)
 		require.Nil(s.T(), err)
-		require.Equal(s.T(), &runningStatementWithNextPage, returnedStatement)
+		require.Equal(s.T(), &runningStatement, returnedStatement)
 	})
 
 	cupaloy.SnapshotT(s.T(), stdout)
 }
 
 func (s *StatementControllerTestSuite) TestExecuteStatementReturnsWhenUserDetaches() {
-	statementToExecute := "select 1;"
+	statementToExecute := "insert into users values ('test');"
 	processedStatement := types.ProcessedStatement{Status: types.PENDING, Principal: "sa-123"}
 	runningStatement := types.ProcessedStatement{Status: types.RUNNING}
 	s.store.EXPECT().ProcessStatement(statementToExecute).Return(&processedStatement, nil)
