@@ -26,17 +26,20 @@ func (g *GoPluginInstaller) CheckVersion(ver *version.Version) error {
 
 	out, err := versionCmd.Output()
 	if err != nil {
-		return errors.NewErrorWithSuggestions(fmt.Sprintf(programNotFoundErrorMsg, "go"), programNotFoundSuggestions)
+		return errors.NewErrorWithSuggestions(
+			fmt.Sprintf(programNotFoundErrorMsg, "go"),
+			programNotFoundSuggestions,
+		)
 	}
 
 	for _, word := range strings.Split(string(out), " ") {
 		if g.IsVersion(word) {
 			installedVer, err := version.NewVersion(strings.TrimPrefix(word, "go"))
 			if err != nil {
-				return errors.Errorf(unableToParseVersionErrorMsg, "go")
+				return fmt.Errorf(unableToParseVersionErrorMsg, "go")
 			}
 			if installedVer.LessThan(ver) {
-				return errors.Errorf(insufficientVersionErrorMsg, "go", installedVer, ver)
+				return fmt.Errorf(insufficientVersionErrorMsg, "go", installedVer, ver)
 			}
 		}
 	}
@@ -49,7 +52,7 @@ func (g *GoPluginInstaller) Install() error {
 	installCmd := exec.NewCommand("go", "install", packageName)
 
 	if _, err := installCmd.Output(); err != nil {
-		return errors.Wrap(err, "failed to run `go install`")
+		return fmt.Errorf("failed to run `go install`: %w", err)
 	}
 
 	return nil
