@@ -11,6 +11,14 @@ var schemaRegistryRoutes = []route{
 	{"/config", handleSRUpdateTopLevelConfig},
 	{"/mode", handleSRUpdateTopLevelMode},
 	{"/compatibility/subjects/{subject}/versions/{version}", handleSRCompatibility},
+	{"/dek-registry/v1/keks", handleSRKeks},
+	{"/dek-registry/v1/keks/{name}", handleSRKek},
+	{"/dek-registry/v1/keks/{name}/undelete", handleSRKekUndelete},
+	{"/dek-registry/v1/keks/{name}/deks", handleSRDeks},
+	{"/dek-registry/v1/keks/{name}/deks/{subject}", handleSRDekSubject},
+	{"/dek-registry/v1/keks/{name}/deks/{subject}/versions", handleSRDekVersions},
+	{"/dek-registry/v1/keks/{name}/deks/{subject}/versions/{version}", handleSRDekVersion},
+	{"/dek-registry/v1/keks/{name}/deks/{subject}/versions/{version}/undelete", handleSRDekUndelete},
 	{"/subjects/{subject}/versions", handleSRSubjectVersions},
 	{"/subjects/{subject}", handleSRSubject},
 	{"/subjects/{subject}/versions/{version}", handleSRSubjectVersion},
